id_inflections.Rd"Breaks" a given continuous variable at the *inflection points* identified by `sizer_aggregate` or `sizer_slice` and creates a column (named `groups`) that contains these group designations. Additionally, it identifies the start and end value of X for each group in two other new columns (named `start` and `end`, respectively)
id_inflections(
raw_data = NULL,
x = NULL,
y = NULL,
sizer_data = NULL,
group_dig = 6
)